pub fn hashment_many<T: SegmentationRules>(
sections: Vec<String>,
rules: &T,
) -> Vec<Hashment>Expand description
Utility function that allows you to hashment a vector of strings at once. Often used in conjunction with extract(). Define and inject your own segmentation rules to modify the segmentation behaviour.